@@ -22,24 +22,19 @@ void orientation_change(AppletInfo *info, PanelWidget *panel);
 void size_change(AppletInfo *info, PanelWidget *panel);
 void back_change(AppletInfo *info, PanelWidget *panel);
 
-void panel_setup(GtkWidget *panel);
 void basep_pos_connect_signals (BasePWidget *basep);
 
 /*send state change to all the panels*/
 void send_state_change(void);
 
-GtkWidget * make_popup_panel_menu (PanelWidget *panel);
-
-PanelData * panel_data_by_id (const char *id);
-
-void status_unparent (GtkWidget *widget);
-
+PanelData *panel_setup(GtkWidget *panel);
+PanelData *panel_data_by_id (const char *id);
 
+GtkWidget *make_popup_panel_menu (PanelWidget *panel);
 
 #define get_panel_parent(appletw) \
 	 (PANEL_WIDGET(GTK_WIDGET(appletw)->parent)->panel_parent)
 
-
 void panel_load_global_config  (void);
 void panel_save_global_config  (void);
 void panel_apply_global_config (void);
@@ -51,6 +46,10 @@ void panel_save_to_gconf     (PanelData *pd);
 
 void panel_register_window_icon (void);
 
+int        panel_monitor_from_toplevel (GtkWidget *panel);
+
+gboolean panel_is_applet_right_stick (GtkWidget *applet);
+
 G_END_DECLS
 
 #endif
